/*****************************************************************************************
 FONCTION DE CONFIGURATION APPELÉE UNIQUEMENT AU DÉMARRAGE EN GARDANT LE BOUTON APPUYÉ
 Gère le stockage en EEPROM
*****************************************************************************************/

void afficheOled(int val, int ligne) { // affiche une valeur = revoir la position sur écran
    oled.setCursor(100,ligne);
    if (val < 100) oled.print(" ");
    if (val < 10) oled.print(" ");
    oled.print(val);
}

int configure(int val, int ligne) {
  afficheOled(val, ligne);
  oldPosition = myEnc.read()/4;

  do {
    long newPosition = myEnc.read()/4;
    if (newPosition != oldPosition) {  
      long intervalEncoder =  millis() - encoderMillis;
      encoderMillis = millis();
      int deltaVal = 10;
      if (intervalEncoder > 200) deltaVal = 1;
      if (newPosition > oldPosition) val=val+deltaVal;  else  val=val-deltaVal;
      if (val<0) val=0;
      oldPosition = newPosition; 
      afficheOled(val, ligne);
      delay(100);
    }
  } while (digitalRead(PIN_BtnEnc) == HIGH);    // attente appui sur bouton

  
  //do {delay(100);} while (digitalRead(PIN_BtnEnc) == LOW); // antirebond
  // attente relachement bouton
  while (digitalRead(PIN_BtnEnc) == LOW) {delay(100);}
  return(val);
}

//////// Configuration de la distance de la zone de mesure de vitesse, de la durée d'arret en gare 
//////// et de l'adresse DCC par défaut en cas de non reconaissance de l'adresse
//////// Adresse de la configuration en EEPROM = eeStart 0x30

void configuration() {
  int valeur;
  oled.set1X();
  
  EEPROM.get(eeStart, gEPConfig);         // lecture record gEPConfig en EEPROM
  if (gEPConfig.vers != EEPVERSION) {     // si l'EEPROM est vierge ou la version a change, on écrit les valeurs par défaut
    gEPConfig.dist = 100;                 // cm
    gEPConfig.arret = 15;                 // s
    gEPConfig.adresse = 3;
    gEPConfig.vers = EEPVERSION;
    gEPConfig.vmin = 15;                  // cran 15
    EEPROM.put(eeStart, gEPConfig);
  }

  if (digitalRead(PIN_BtnEnc) == LOW) {      // mode configuration en appuyant sur BOK au démarrage
    oled.clear();
    oled.setCursor(0,0);
    oled.print(F("Config v"));                     // affichage version "v011"
    if (gEPConfig.vers < 100) oled.print(" ");
    if (gEPConfig.vers < 10) oled.print(" ");
    oled.print(gEPConfig.vers);
    delay(2000);
    //gEncoder == false;
    ///////////////////////// configuration distance zone C ou D 
    oled.setCursor(0,0); 
    oled.print(F("Longueur zB "));
    valeur = gEPConfig.dist;             // valeur initiale
    if (valeur > 600) valeur = 600;
    gEPConfig.dist = configure(valeur, 0);
    ///////////////////////// configuration durée arret en gare   
    oled.setCursor(0,2);
    oled.print(F("Duree Arret   "));
    valeur = gEPConfig.arret;
    if (valeur > 100) valeur = 100;
    gEPConfig.arret = configure(valeur, 2);
    ///////////////////////// configuration adresse DCC par défaut   Si adresse == 0 => mode PWM
    oled.setCursor(0,4);
    oled.print(F("Adresse DCC   "));
    valeur = gEPConfig.adresse;
    if (valeur > 999) valeur = 999;
    gEPConfig.adresse = configure(valeur, 4);
    ///////////////////////// configuration vitesse minimale
    oled.setCursor(0,6);
    oled.print(F("Vitesse min   "));
    valeur = gEPConfig.vmin;
    if (valeur < 2) valeur = 2;
    gEPConfig.vmin = configure(valeur, 6);
    //////////////////////// enregistrement
    gEPConfig.vers = EEPVERSION;
    oled.setCursor(0,0);
    oled.print(F("Enregistrement.."));
    EEPROM.put(eeStart, gEPConfig);  
    //oled.set2X();
    delay(2000);       
    oled.clear();
  }
}
